% reset_mld
%
% This script replaces the PE mixing layer depth with a mixed layer depth
% determined from potential density.

%-------------------------------------------------------------------------------
% Set scaling parameters.
%-------------------------------------------------------------------------------

m2cm = 100;

%-------------------------------------------------------------------------------
% Get name of input file containing run parameters.
%-------------------------------------------------------------------------------

parmfiledef = 'reset_mld.in';

parmfile = input (['Enter name of parameter input file [',parmfiledef, ...
                   ']: '],'s');
if isempty(parmfile)
   parmfile = parmfiledef;
end;

clear parmfiledef;

%-------------------------------------------------------------------------------
% Read run parameters.
%-------------------------------------------------------------------------------

[dpden,time,pefile] = resetmld_parm (parmfile);

if isempty (pefile)
   disp (' ');
   disp ('***Error:  RESET_MLD - unable to read input file:');
   disp (['           ',setstr(34),parmfile,setstr(34)]);
   disp (' ');
   return;
end;

clear parmfile;

%-------------------------------------------------------------------------------
% Open PE file.
%-------------------------------------------------------------------------------

[ncid,timchkd] = peopen (dpden,time,pefile);

if isempty (timchkd)
   disp (' ');
   disp ('***Error:  RESET_MLD - unable to work with PE netCDF file:');
   disp (['           ',setstr(34),pefile,setstr(34)]);
   disp (' ');
   return;
end;

clear time;

%-------------------------------------------------------------------------------
% Reset mixed layer depth.
%-------------------------------------------------------------------------------

name = 'mld';

for n = 1:length(timchkd)
   mld = find_mld (ncid,timchkd(n),dpden);
   if isempty(mld)
      disp (' ');
      disp (['***Error:  RESET_MLD - unable to compute mixed layer depth ', ...
             'at time ',num2str(timchkd(n)),' for PE netCDF file:']);
      disp (['           ',setstr(34),pefile,setstr(34)]);
      disp (' ');
      return;
   end;
   ncid{name}(timchkd(n),:,:) = abs(mld) .* m2cm;
end;

clear dpden m2cm mld n name timchkd;

%-------------------------------------------------------------------------------
% Close PE file.
%-------------------------------------------------------------------------------

status = close (ncid);

if ~isempty (status)
   disp (' ');
   disp ('***Error:  RESET_MLD - unable to close PE netCDF file:');
   disp (['           ',setstr(34),pefile,setstr(34)]);
   disp (' ');
   return;
end;

clear ncid pefile status;
