function [dpden,time,pefile] = resetmld_parm (parmfile);
%
% function [dpden,time,pefile] = resetmld_parm (parmfile);
%
% This function reads in the parameters to run the replacement of PE mixing
% layer depth with mixED layer depth.
%
% ------
% Input:
% ------
%
%    PARMFILE    Name of parameter input file.
%
% -------
% Output:
% -------
%
%    DPDEN       Cut-off density for mixed layer.  (kg/m^3)
%    TIME        Time indices to replace.
%    PEFILE      Name of PE file to modify.

%-------------------------------------------------------------------------------
% Set default values.
%-------------------------------------------------------------------------------

dpden  = [];
time   = [];
pefile = '';

%-------------------------------------------------------------------------------
% Open parameter input file.
%-------------------------------------------------------------------------------

[fid,mess] = fopen (parmfile,'r');

if (fid<0)
   disp (' ');
   disp ('***Error:  RESETMLD_PARM - unable to open parameter input file:');
   disp (['           ',setstr(34),parmfile,setstr(34)]);
   disp (['           ',setstr(34),mess,setstr(34)]);
   status = fid;
   return;
end;

%-------------------------------------------------------------------------------
% Read run parameters.
%-------------------------------------------------------------------------------

dpden  = num_read (fid);
time   = num_read (fid);
pefile = fgetl (fid);

%-------------------------------------------------------------------------------
% Close parameter input file.
%-------------------------------------------------------------------------------

status = fclose (fid);

if (status<0)
   disp (' ');
   disp ('***Error:  RESETMLD_PARM - unable to close parameter input file:');
   disp (['           ',setstr(34),parmfile,setstr(34)]);
end;
